#
# spec file for package liboping
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           liboping
Version:        1.8.0
Release:        6.3
%define         soname 0
Summary:        Multiple Host Ping Library that supports ICMPv4 and ICMPv6
Source:         http://verplant.org/liboping/files/liboping-%{version}.tar.bz2
Source2:        baselibs.conf
Source99:       %{name}-rpmlintrc
Patch1:         liboping-perl_vendor.patch
Patch2:         liboping-conditional_IPV6_TCLASS.patch
Url:            http://verplant.org/liboping/
Group:          System/Libraries
License:        LGPL-2.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.65
BuildRequires:  automake
BuildRequires:  gcc  
BuildRequires:  glibc-devel
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkg-config
BuildRequires:  libtool

%description
liboping is a C library for measuring network latency using ICMP echo
requests. It can send to and receive packets from multiple hosts in parallel,
which is nice for monitoring applications. Both IPv4 and IPv6 are supported
transparently for the programmer and user.

%package -n liboping%{soname}
Summary:        Multiple Host Ping Library that supports ICMPv4 and ICMPv6
Group:          System/Libraries
Provides:       liboping = %{version}-%{release}

%description -n liboping%{soname}
liboping is a C library for measuring network latency using ICMP echo
requests. It can send to and receive packets from multiple hosts in parallel,
which is nice for monitoring applications. Both IPv4 and IPv6 are supported
transparently for the programmer and user.

A program called oping is available on the oping package to show the
simplicity and potential of the library and provide the functionality at the
command line.

%package -n liboping-devel
Summary:        Multiple Host Ping Library that supports ICMPv4 and ICMPv6
Requires:       %{name} = %{version}-%{release}
Group:          Development/Libraries/Other

%description -n liboping-devel
liboping is a C library for measuring network latency using ICMP echo
requests. It can send to and receive packets from multiple hosts in parallel,
which is nice for monitoring applications. Both IPv4 and IPv6 are supported
transparently for the programmer and user.

This package includes the header and shared library link, required for
building applications or libraries that use %{name}.
This package is not needed at runtime.

%package -n oping
Summary:        Multiple Host Ping that supports ICMPv4 and ICMPv6
Requires:       %{name} = %{version}-%{release}
Group:          Productivity/Networking/Other
License:        GPL-2.0

%description -n oping
oping is for measuring network latency using ICMP echo requests. It can send
to and receive packets from multiple hosts in parallel, which is nice for
monitoring applications. Both IPv4 and IPv6 are supported transparently.

%package -n noping
Summary:        Multiple Host Ping that supports ICMPv4 and ICMPv6
Requires:       %{name} = %{version}-%{release}
Group:          Productivity/Networking/Other
License:        GPL-2.0

%description -n noping
noping continuously pings lists of hosts, displays ping statistics "live"
and highlights aberrant round-trip times.

%package -n perl-Net-Oping
Summary:        Multiple Host Ping that supports ICMPv4 and ICMPv6
Group:          Development/Libraries/Perl
Requires:       perl = %{perl_version}

%description -n perl-Net-Oping
Net::Oping is for measuring network latency using ICMP echo requests.
It can send to and receive packets from multiple hosts in parallel, which is
nice for monitoring applications. Both IPv4 and IPv6 are supported
transparently.

%prep
%setup -q
%patch1 -p0
%patch2 -p1

%__sed -i 's/-Werror//g' src/Makefile*
# Do not use versioned automake binary for backward compatibility
%__sed -i 's/-${am__api_version}//g' configure

%build
aclocal && automake
%configure \
    --with-perl-bindings="INSTALLDIRS=vendor"
%__make -C bindings perl/Makefile

make %{?_smp_mflags}

%install
%__sed -e 's|perl5/site_perl/|perl5/vendor_perl/|g' bindings/perl/Makefile
%makeinstall
%__rm "%{buildroot}%{_libdir}"/*.la

%perl_process_packlist

%__rm -f "%{buildroot}/var/adm/perl-modules/%{name}"

%post   -n liboping%{soname} -p /sbin/ldconfig

%postun -n liboping%{soname} -p /sbin/ldconfig

%files -n liboping%{soname}
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_libdir}/liboping.so.%{soname}
%{_libdir}/liboping.so.%{soname}.*.*

%files -n liboping-devel
%defattr(-,root,root)
%{_includedir}/oping.h
%{_libdir}/liboping.so
%{_libdir}/liboping.a
%{_libdir}/pkgconfig/liboping.pc
%{_mandir}/man3/*.3%{ext_man}

%files -n oping
%defattr(-,root,root)
%{_bindir}/oping
%{_mandir}/man8/oping.8%{ext_man}

%files -n noping
%defattr(-,root,root)
%{_bindir}/noping

%files -n perl-Net-Oping
%defattr(-,root,root)
%dir %{perl_vendorarch}/Net
%{perl_vendorarch}/Net/Oping.pm
%dir %{perl_vendorarch}/auto/Net
%{perl_vendorarch}/auto/Net/Oping
%{perl_man3dir}/Net::Oping.%{perl_man3ext}%{ext_man}

%changelog
* Mon Mar 30 2015 p.drouand@gmail.com
- Add support for distributions which provide automake older than
  1.14
- Add pkg-config build require; needed to find devel dependencies
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 1.8.0
  * oping, noping: Average and standard deviation have been removed from
  the status output, which show median and 95th percentile instead.
  The percentile can be chosen with the "-P" option.
  * noping: The additional graph types "histogram" and "boxplot" have
    been added, which can be selected with the "-g" option.
- Spec file refactoring
- liboping requires automake >= 1.14; fix version dependency
- Do not copy manâges in package documentation directory
* Wed Feb 15 2012 lars@linux-schulserver.de
- update to 1.6.2:
  * Build system: Setting capabilities and the set-UID bit has been made
    more fault-tolerant, so that it will work with Debian's fakeroot(1)
    utility.
  * src/liboping.c: Fixed a compiler warning about an non-static format
    string. Thanks to Brian Edwards for pointing this out.
- specfile cleanup
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs for package
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Correct description of SRPM
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- update to 1.6.1:
  * compatibility with ncurses 5.8 has been added to the "noping" application
* Wed Jan 26 2011 pascal.bleser@opensuse.org
- update to 1.6.0:
  * improved timing information accuracy on systems that provide the
    SO_TIMESTAMP socket option
* Thu Nov 18 2010 pascal.bleser@opensuse.org
- update to 1.5.1:
  * an alias for the "Voice Admit" PHB (RFC 5865) has been added to the QoS
    option of oping
  * compiler errors have been fixed and outdated documentation has been updated
* Fri Oct 29 2010 pascal.bleser@opensuse.org
- add perl module
- update to 1.5.0:
  * adds the ability to set the Quality of Service (QoS) byte of outgoing
    packets and read the QoS byte of incoming packets; support for this feature
    has been added to the oping and noping command line utilities
  * the license of the library has been changed to LGPL 2.1
* Mon Jun 14 2010 pascal.bleser@opensuse.org
- removed liboping-no_IPV6_RECVHOPLIMIT.patch (merged upstream)
* Mon Jun 14 2010 pascal.bleser@opensuse.org
- update to 1.4.0:
  * a new ncurses-based front-end to liboping, called noping, has been added:
    the new command line application displays ping statistics "live" and
    highlights aberrant round-trip times
- fixed whitespaces in spec file
- packaged new noping binary into its own subpackage ("noping")
* Sun Dec 20 2009 pascal.bleser@opensuse.org
- update to 1.3.4:
  * improved handling of sockets with error conditions: previously, such an
    error could lead to indefinite busy looping
  * improved oping utility to allow reading from files even when running
  * SetUID-root: privileges are dropped temporarily when supported by the
    system
  * an off-by-one error has been fixed in the Perl bindings
* Sat Sep 26 2009 kkaempf@suse.de
- rename .spec to match liboping0 package name
* Mon Jul 27 2009 pascal.bleser@opensuse.org
- update to 1.3.2:
  * ability to specify the network device to use has been added to the library
  * the included “oping” application has been enhanced to provide this
    functionality and allow reading hostnames from a file or standard input
  * argument checking has been improved
  * a bug which could lead to incorrect measurements has been fixed
* Tue May 12 2009 pascal.bleser@opensuse.org
- moved to openSUSE Build Service
- update to 1.1.2
